@@ -1,6 +1,6 @@
 package Catmandu::ArXiv;
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 =head1 NAME
 
@@ -8,16 +8,12 @@ Catmandu::ArXiv - Catmandu modules for working with ArXiv data.
 
 =head1 STATUS
 
-=begin HTML
-
 <p>
 <a href="https://travis-ci.org/LibreCat/Catmandu-ArXiv"><img src="https://travis-ci.org/LibreCat/Catmandu-ArXiv.svg?branch=master" alt="build status" /></a>
-<a href="https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/"><img src="https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/badge.png?branch=master" alt="coverage status" /></a>
+<a href="https://coveralls.io/r/LibreCat/Catmandu-ArXiv/"><img src="https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/badge.png?branch=master" alt="coverage status" /></a>
 <a href="http://cpants.cpanauthors.org/dist/Catmandu-ArXiv"><img src="http://cpants.cpanauthors.org/dist/Catmandu-ArXiv.png" alt="kwalitee score" /></a>
 </p>
 
-=end HTML
-
 =head1 MODULES
 
 =over
@@ -36,6 +32,16 @@ Catmandu::ArXiv - Catmandu modules for working with ArXiv data.
 
 =back
 
+=head1 MAINTAINER
+
+=over
+
+=item * Vitali Peil
+
+=item * Christian Pietsch
+
+=back
+
 =head1 LICENSE AND COPYRIGHT
 
 This program is free software; you can redistribute it and/or modify it
